abctools.Parser
===============

.. abjad-lineage:: abjad.tools.abctools.Parser.Parser.Parser

.. autoclass:: abjad.tools.abctools.Parser.Parser.Parser
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.debug
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.lexer
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.lexer_rules_object
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.logger
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.logger_path
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.output_path
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.parser
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.parser_rules_object
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.pickle_path
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.tokenize
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__call__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__eq__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__ge__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__gt__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__le__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__lt__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__ne__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__repr__
   :noindex:
